@@ -9,7 +9,7 @@ check_named_list_or_null <- function(value) {
 	if (!is.list(value)) {
 		stop("Value must be a NULL or a list.")
 	}
-	if (any(names(value) == "")) {
+	if (is.null(names(value)) || any(names(value) == "")) {
 		stop("All list elements must be named.")
 	}
 	if (!identical(names(value), unique(names(value)))) {
@@ -21,7 +21,11 @@ s7_check_is_valid_list_dispatch <- function(x, function_name) {
 	cls <- S7_class(x)
 	if (!is.null(cls)) {
 		stop(
-			sprintf("No method found for `%s()` for class `%s`.", function_name, cls)
+			sprintf(
+				"No method found for `%s()` for class `%s`.",
+				function_name,
+				cls@name
+			)
 		)
 	}
 }
@@ -38,39 +42,35 @@ s7_check_is_valid_list_dispatch <- function(x, function_name) {
 	}
 }
 
-# Generic: ._call_provided_f ####
-._call_provided_f <- new_generic(
-	name = "._call_provided_f",
-	dispatch_args = c(".f", "args"),
-	fun = function(.f, args = NULL, x, ...) {
-		S7_dispatch()
-	}
-)
-
-## Method: function, NULL ####
-method(
-	._call_provided_f,
-	list(class_function, NULL)
-) <- function(.f, args, x) {
-	.f(x)
-}
-
-## Method: function, list ####
-method(
-	._call_provided_f,
-	list(class_function, class_list)
-) <- function(.f, args, x) {
-	do.call(.f, c(list(x = x, args)))
-}
-
 set_names <- function(object = nm, nm) {
 	names(object) <- nm
 	return(object)
 }
 
-as_list_ <- function(x) {
-	if (is.null(x)) {
-		return(list(x))
+all_trues <- function(x) {
+	all_something(x, TRUE)
+}
+
+all_something <- function(x, something) {
+	rep(something, len(x))
+}
+
+len <- function(x) {
+	len <- dim(x)[[1]]
+	if (is.null(len)) {
+		len <- length(x)
 	}
-	return(as.list(x))
+	return(len)
+}
+
+check_is_nonempty_string <- function(x) {
+	if (
+		!identical(length(x), 1L) ||
+			is.null(x) ||
+			is.na(x) ||
+			!is.character(x) ||
+			identical(x, "")
+	) {
+		stop(sprintf("`%s` must be a non-empty string", deparse(substitute(x))))
+	}
 }
